Billabong
=========

A reliable, distributed, encrypted storage and backup solution for all
of your photos, videos, music and other static data.

Usage
-----

::

    alias bong="python3 -m billabong"

::

    Usage: bong COMMAND <options>

    Available commands:
     add
     blobs
     check   Check the validity of all blobs and metadata
     echo
     get
     info
     ls
     pull    Pull blobs from sync storage
     push    Push blobs to sync storage
     search
     status  Print a global status of the inventory and storage.

    Use 'bong <command> --help' for individual command help.

